==> sddm_0.14.0.orig.tar.gz: sddm-0.14.0/data/translations/sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Vitajte v %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Pozor, je aktívny Caps Lock!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Rozloženie klávesnice</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Prihlásiť sa</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Prihlásenie zlyhalo</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Prihlásenie bolo úspešné</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Zadajte svoje užívateľské meno a heslo</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reštartovať</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Relácia</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Užívateľské meno</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Vyberte váš užívateľský účet a zadajte heslo</translation>
    </message>
</context>
</TS>

==> sddm_0.17.0.orig.tar.gz: sddm-0.17.0/data/translations/sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Vitajte v %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Pozor, je aktívny Caps Lock!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Rozloženie klávesnice</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Prihlásiť sa</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Prihlásenie zlyhalo</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Prihlásenie bolo úspešné</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Zadajte svoje užívateľské meno a heslo</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reštartovať</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Relácia</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Užívateľské meno</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Vyberte váš užívateľský účet a zadajte heslo</translation>
    </message>
</context>
</TS>
